From: Jan Kiszka <jan.kis...@siemens.com>

These are there because of the file format.

Signed-off-by: Jan Kiszka <jan.kis...@siemens.com>
---
 scripts/cppcheck.sh | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/scripts/cppcheck.sh b/scripts/cppcheck.sh
index b01421f..af5f337 100755
--- a/scripts/cppcheck.sh
+++ b/scripts/cppcheck.sh
@@ -40,8 +40,9 @@ suppress+=" --suppress=comparePointers:main.c"
 suppress+=" --suppress=unusedFunction:drivers/watchdog/amdfch_wdt.c"
 # False positive, noreturn is not recognized
 suppress+=" --suppress=nullPointerRedundantCheck:kernel-stub/main.c"
 # Avoid noise regarding Ignore* fields
 suppress+=" --suppress=unusedStructMember:kernel-stub/main.c"
+suppress+=" --suppress=unusedStructMember:kernel-stub/fdt.c"
 # Not applicable because of API requirements
 suppress+=" --suppress=constParameter:drivers/watchdog/ipc4x7e_wdt.c"
 suppress+=" --suppress=constParameter:drivers/watchdog/w83627hf_wdt.c"
@@ -40,8 +40,9 @@ suppress+=" --suppress=comparePointers:main.c"
 # False positive, noreturn is not recognized
 suppress+=" --suppress=nullPointerRedundantCheck:kernel-stub/main.c"
-# Avoid noise regarding Ignore* fields
+# Avoid noise regarding Ignore* or otherwise unused fields
 suppress+=" --suppress=unusedStructMember:kernel-stub/main.c"
-- 
2.35.3

-- 
You received this message because you are subscribed to the Google Groups "EFI 
Boot Guard" group.
To unsubscribe from this group and stop receiving emails from it, send an email 
to efibootguard-dev+unsubscr...@googlegroups.com.
To view this discussion on the web visit 
https://groups.google.com/d/msgid/efibootguard-dev/1c99ccf7293ee586a6ee2f898e51d234eef19ffb.1697736989.git.jan.kiszka%40siemens.com.

Reply via email to